"""Constant for Python file content with multiple top-level definitions."""

SAMPLE_MULTIPLE_DEFINITIONS_CONTENT: str = """def function_one():
    pass

def function_two():
    pass

class MyClass:
    pass
"""
