"""Config package for structure-lint."""

from kdaquila_structure_lint.config._functions import load_config
from kdaquila_structure_lint.config._types import Config

__all__ = ["Config", "load_config"]
