"""Constants package for config defaults."""

from kdaquila_structure_lint.config._constants.defaults import (
    DEFAULT_ENABLED,
    DEFAULT_FILES_ALLOWED_ANYWHERE,
    DEFAULT_FOLDER_DEPTH,
    DEFAULT_IGNORED_FOLDERS,
    DEFAULT_LINE_LIMITS_ENABLED,
    DEFAULT_MAX_LINES,
    DEFAULT_ONE_PER_FILE_ENABLED,
    DEFAULT_SEARCH_PATHS,
    DEFAULT_STANDARD_FOLDERS,
    DEFAULT_STRUCTURE_ENABLED,
)

__all__ = [
    "DEFAULT_ENABLED",
    "DEFAULT_FILES_ALLOWED_ANYWHERE",
    "DEFAULT_FOLDER_DEPTH",
    "DEFAULT_IGNORED_FOLDERS",
    "DEFAULT_LINE_LIMITS_ENABLED",
    "DEFAULT_MAX_LINES",
    "DEFAULT_ONE_PER_FILE_ENABLED",
    "DEFAULT_SEARCH_PATHS",
    "DEFAULT_STANDARD_FOLDERS",
    "DEFAULT_STRUCTURE_ENABLED",
]
