"""TypeScript definition counter sub-feature."""

from kdaquila_structure_lint.definition_counter.typescript._functions.count_typescript_definitions import (  # noqa: E501
    count_typescript_definitions,
)

__all__ = ["count_typescript_definitions"]
